@@ -574,21 +574,13 @@ static gpointer backup_thread (gpointer data)
                 return NULL;
             }
         }
-        else
-        {
-            if (sys_printf (SUDO_PREFIX "parted -s %s set %d lba off", dst_dev, parts[p].pnum))
-            {
-                terminate_dialog (_("Could not set flags."));
-                return NULL;
-            }
-        }
         CANCEL_CHECK;
     }
 
     if (getenv ("WAYLAND_DISPLAY"))
         sys_printf ("wfpanelctl ejecter %s", dst_dev);
     else
-        sys_printf ("lxpanelctl command ejecter %s", dst_dev);
+        sys_printf ("lxpanelctl-pi command ejecter %s", dst_dev);
     terminate_dialog (_("Copy complete."));
     return NULL;
 }
